@@ -12,7 +12,7 @@ from warnings import warn
 from .parsers import *
 from .colourpickers import *
 from .constants import Errors, Constants
-from .config import Config
+from .config import DefaultConfig
 
 
 @contextmanager
@@ -27,13 +27,13 @@ def set_value(target_set, value):
 
 class Scorer:
     def __init__(
-            self, dir_path: str,
-            colour_picker: Type[ColourPicker] = LayerScoreColourPicker,
+            self, dir_path: str, config=DefaultConfig,
             custom_labeller: Optional[Callable[["Scorer", str], Optional[str]]] = None,
             custom_parsers: Iterable[Type[Parser]] = (),
-            custom_filters: Iterable[Callable[[str], bool]] = (),
-            use_default_filters: bool = False
+            custom_filters: Iterable[Callable[[str], bool]] = ()
     ):
+        self._config = config
+
         self._dir_path = path.abspath(dir_path)
         # Filtered files do not increment the score of any dependency trees they are in, and are excluded from output
         self._filters = set(custom_filters)
@@ -43,12 +43,12 @@ class Scorer:
         for parser_cls in custom_parsers:
             self._parsers.add(parser_cls)
 
-        if use_default_filters:
+        if self._config.USE_DEFAULT_FILTERS:
             for parser_cls in self._parsers:
-                for func in parser_cls.filters:
+                for func in parser_cls.FILTERS:
                     self._filters.add(func)
 
-        self._colour_picker = colour_picker(self)
+        self._colour_picker = self._config.COLOUR_PICKER_CLS(self)
 
         # Layer score indicates how many layers of imports a file relies on
         self._layer_scores = {}
@@ -62,6 +62,10 @@ class Scorer:
 
         setrecursionlimit(10000)
 
+    @property
+    def config(self):
+        return self._config
+
     @property
     def dir_path(self) -> str:
         return self._dir_path
@@ -281,7 +285,7 @@ class Scorer:
             node_colour, node_border_colour = self._colour_picker.get(parent)
             subgraph.node(
                 parent_node_id, self.get_label(parent),
-                color=node_border_colour, style="filled", fillcolor=node_colour, **Config.ranked_styles["node"]
+                color=node_border_colour, style="filled", fillcolor=node_colour, **self._config.RANKED_STYLES["node"]
             )
 
         for parent_index, parent in enumerate(connections_working):
@@ -292,7 +296,7 @@ class Scorer:
                 child_node_id = node_ids[child]
 
                 edge_colour = self._colour_picker.get(child)[1]
-                graph.edge(child_node_id, parent_node_id, color=edge_colour, **Config.ranked_styles["edge"])
+                graph.edge(child_node_id, parent_node_id, color=edge_colour, **self._config.RANKED_STYLES["edge"])
 
         for subgraph in subgraphs.values():
             graph.subgraph(subgraph)
@@ -306,8 +310,8 @@ class Scorer:
 
         label_delimiter = "▼\n"
         if (result := self._custom_labeller(self, file_path)) is None:
-            result = file_path.replace(self._dir_path + Constants.path_delimiter, "")
-            result = result.replace(Constants.path_delimiter, label_delimiter)
+            result = file_path.replace(self._dir_path + Constants.PATH_DELIMITER, "")
+            result = result.replace(Constants.PATH_DELIMITER, label_delimiter)
 
         if scorebar_length > 0:  # 0 or less will not generate a scorebar at all
             file_layer = self._layer_scores[file_path]
